import * as React from 'react';
import { DayClickEventHandler, DayPickerProps, MonthChangeEventHandler } from '../../types';
/** Represent the props to attach to the input field. */
export interface UseInputFieldProps {
    /** Event handler for the blur event. */
    onBlur: React.FocusEventHandler;
    /** Event handler for the change event. */
    onChange: React.ChangeEventHandler<HTMLInputElement>;
    /** Event handler for the focus event. */
    onFocus: React.FocusEventHandler;
    /** The value of the input field */
    value: string;
    /** The input field placeholder */
    placeholder?: string;
}
/** Represent the props to attach to DayPicker component. */
export interface UseInputDayPickerProps {
    mode: 'custom';
    fromDate?: Date;
    locale: Locale;
    min: number;
    month: Date;
    onDayClick: DayClickEventHandler;
    onMonthChange: MonthChangeEventHandler;
    selected: Date | undefined;
    toDate?: Date;
    today: Date;
}
export interface UseInputOptions extends Pick<DayPickerProps, 'locale' | 'fromDate' | 'toDate' | 'fromMonth' | 'toMonth' | 'fromYear' | 'toYear' | 'today'> {
    /** The initially selected date */
    defaultSelected?: Date;
    /** The format string for formatting the input field. See https://date-fns.org/docs/format for a list of format strings. Default to `PP`. */
    format?: string;
    /** Make the selection required. */
    required?: boolean;
}
/** Represent the value returned by [[useInput]]. */
export interface UseInput {
    /** The props to pass to a DayPicker component: `<DayPicker {...dayPickerProps} />` */
    dayPickerProps: UseInputDayPickerProps;
    /** The props to pass to an input field: `<input {...inputProps} />` */
    inputProps: UseInputFieldProps;
    /** A function to reset to the initial state. */
    reset: () => void;
    /** A function to set the selected day. */
    setSelected: (day: Date) => void;
}
/** Return props and setters for binding an input field to DayPicker. */
export declare function useInput(options?: UseInputOptions): UseInput;
